@@ -2,13 +2,12 @@
 
 use core::convert::TryFrom;
 use crate::core::{ major, marker, types };
+use crate::util::ScopeGuard;
 pub use crate::error::DecodeError as Error;
 
 #[cfg(feature = "use_alloc")]
 use crate::alloc::{ vec::Vec, string::String };
 
-#[cfg(feature = "use_alloc")]
-use crate::util::ScopeGuard;
 
 /// Read trait
 ///
@@ -152,6 +151,20 @@ fn pull_exact<'a, R: Read<'a>>(reader: &mut R, mut buf: &mut [u8]) -> Result<(),
     Ok(())
 }
 
+#[inline]
+fn skip_exact<'de, R: Read<'de>>(reader: &mut R, mut len: usize) -> Result<(), R::Error> {
+    while len != 0 {
+        let buf = reader.fill(len)?;
+        let buf = buf.as_ref();
+
+        let buflen = core::cmp::min(len, buf.len());
+        reader.advance(buflen);
+        len -= buflen;
+    }
+
+    Ok(())
+}
+
 pub(crate) struct TypeNum {
     major_limit: u8,
     byte: u8
@@ -266,7 +279,7 @@ macro_rules! decode_ix {
             impl<'a> Decode<'a> for $t {
                 #[inline]
                 fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
-                    match byte >> 5 {
+                    match if_major(byte) {
                         major::UNSIGNED => {
                             let v = TypeNum::new(!(major::UNSIGNED << 5), byte).$decode_fn(reader)?;
                             <$t>::try_from(v).map_err(Error::CastOverflow)
@@ -328,7 +341,7 @@ fn decode_x128<'a, R: Read<'a>>(name: &'static str, reader: &mut R) -> Result<[u
 impl<'a> Decode<'a> for u128 {
     #[inline]
     fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
-        if byte >> 5 == major::UNSIGNED {
+        if if_major(byte) == major::UNSIGNED {
             u64::decode_with(byte, reader).map(Into::into)
         } else {
             let tag = TypeNum::new(!(major::TAG << 5), byte).decode_u8(reader)?;
@@ -348,7 +361,7 @@ impl<'a> Decode<'a> for u128 {
 impl<'a> Decode<'a> for i128 {
     #[inline]
     fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
-        match byte >> 5 {
+        match if_major(byte) {
             major::UNSIGNED => u64::decode_with(byte, reader).map(Into::into),
             major::NEGATIVE => i64::decode_with(byte, reader).map(Into::into),
             _ => {
@@ -772,6 +785,77 @@ impl<'a> Decode<'a> for f64 {
     }
 }
 
+/// Ignore an arbitrary object
+pub struct IgnoredAny;
+
+impl<'a> Decode<'a> for IgnoredAny {
+    fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
+        if !reader.step_in() {
+            return Err(Error::DepthLimit);
+        }
+        let mut reader = ScopeGuard(reader, |reader| reader.step_out());
+        let reader = &mut *reader;
+
+        match if_major(byte) {
+            major @ major::UNSIGNED | major @ major::NEGATIVE => {
+                let skip = match byte & !(major << 5) {
+                    0 ..= 0x17 => 0,
+                    0x18 => 1,
+                    0x19 => 2,
+                    0x1a => 4,
+                    0x1b => 8,
+                    _ => return Err(Error::TypeMismatch {
+                        name: "ignore-any",
+                        byte
+                    })
+                };
+                skip_exact(reader, skip)?;
+            },
+            major @ major::BYTES | major @ major::STRING |
+            major @ major::ARRAY | major @ major::MAP => {
+                if let Some(len) = decode_len(major, byte, reader)? {
+                    match major {
+                        major::BYTES | major::STRING => skip_exact(reader, len)?,
+                        major::ARRAY | major::MAP => for _ in 0..len {
+                            let _ignore = IgnoredAny::decode(reader)?;
+
+                            if major == major::MAP {
+                                let _ignore = IgnoredAny::decode(reader)?;
+                            }
+                        },
+                        _ => ()
+                    }
+                } else {
+                    while !is_break(reader)? {
+                        let _ignore = IgnoredAny::decode(reader)?;
+
+                        if major == major::MAP {
+                            let _ignore = IgnoredAny::decode(reader)?;
+                        }
+                    }
+                }
+            },
+            major @ major::TAG => {
+                let _tag = TypeNum::new(!(major << 5), byte).decode_u8(reader)?;
+                let _ignore = IgnoredAny::decode(reader)?;
+            },
+            major::SIMPLE => match byte {
+                marker::FALSE
+                    | marker::TRUE
+                    | marker::NULL
+                    | marker::UNDEFINED => (),
+                marker::F16 => skip_exact(reader, 2)?,
+                marker::F32 => skip_exact(reader, 4)?,
+                marker::F64 => skip_exact(reader, 8)?,
+                _ => return Err(Error::Unsupported { byte })
+            },
+            _ => return Err(Error::Unsupported { byte })
+        }
+
+        Ok(IgnoredAny)
+    }
+}
+
 #[inline]
 pub fn is_break<'a, R: Read<'a>>(reader: &mut R) -> Result<bool, Error<R::Error>> {
     if peek_one(reader)? == marker::BREAK {
@@ -781,3 +865,9 @@ pub fn is_break<'a, R: Read<'a>>(reader: &mut R) -> Result<bool, Error<R::Error>
         Ok(false)
     }
 }
+
+/// Determine the object type from the given byte.
+#[inline]
+pub fn if_major(byte: u8) -> u8 {
+    byte >> 5
+}
